import type { Resolver } from './index.js';
export declare type WebpackResolverOptions = {
    /** Working directory path. */
    cwd?: string | undefined;
    /**
     * The option compatible with sass's `--load-path`. It is an array of relative or absolute paths.
     * @example ['src/styles']
     * @example ['/home/user/repository/src/styles']
     */
    sassLoadPaths?: string[] | undefined;
    /**
     * The option compatible with less's `--include-path`. It is an array of relative or absolute paths.
     * @example ['src/styles']
     * @example ['/home/user/repository/src/styles']
     */
    lessIncludePaths?: string[] | undefined;
    /**
     * The option compatible with webpack's `resolve.alias`. It is an object consisting of a pair of alias names and relative or absolute paths.
     * @example { style: 'src/styles', '@': 'src' }
     * @example { style: '/home/user/repository/src/styles', '@': '/home/user/repository/src' }
     */
    webpackResolveAlias?: Record<string, string> | undefined;
};
export declare const createWebpackResolver: (webpackResolverOptions?: WebpackResolverOptions | undefined) => Resolver;
