import type { Resolver } from './resolver/index.js';
import { type Transformer } from './transformer/index.js';
export declare type Watcher = {
    close: () => Promise<void>;
};
export declare type LocalsConvention = 'camelCase' | 'camelCaseOnly' | 'dashes' | 'dashesOnly' | undefined;
export interface RunnerOptions {
    pattern: string;
    watch?: boolean | undefined;
    localsConvention?: LocalsConvention | undefined;
    declarationMap?: boolean | undefined;
    transformer?: Transformer | undefined;
    resolver?: Resolver | undefined;
    /**
     * The option compatible with sass's `--load-path`. It is an array of relative or absolute paths.
     * @example ['src/styles']
     * @example ['/home/user/repository/src/styles']
     */
    sassLoadPaths?: string[] | undefined;
    /**
     * The option compatible with less's `--include-path`. It is an array of relative or absolute paths.
     * @example ['src/styles']
     * @example ['/home/user/repository/src/styles']
     */
    lessIncludePaths?: string[] | undefined;
    /**
     * The option compatible with webpack's `resolve.alias`. It is an object consisting of a pair of alias names and relative or absolute paths.
     * @example { style: 'src/styles', '@': 'src' }
     * @example { style: '/home/user/repository/src/styles', '@': '/home/user/repository/src' }
     */
    webpackResolveAlias?: Record<string, string> | undefined;
    /**
     * The option compatible with postcss's `--config`. It is a relative or absolute path.
     * @example '.'
     * @example 'postcss.config.js'
     * @example '/home/user/repository/src'
     */
    postcssConfig?: string | undefined;
    /**
     * Only generate .d.ts and .d.ts.map for changed files.
     * @default true
     */
    cache?: boolean | undefined;
    /**
     * Strategy for the cache to use for detecting changed files.
     * @default 'content'
     */
    cacheStrategy?: 'content' | 'metadata' | undefined;
    /**
     * Silent output. Do not show "files written" messages.
     * @default false
     */
    silent?: boolean | undefined;
    /** Working directory path. */
    cwd?: string | undefined;
}
declare type OverrideProp<T, K extends keyof T, V extends T[K]> = Omit<T, K> & {
    [P in K]: V;
};
/**
 * Run typed-css-module.
 * @param options Runner options.
 * @returns Returns `Promise<Watcher>` if `options.watch` is `true`, `Promise<void>` if `false`.
 */
export declare function run(options: OverrideProp<RunnerOptions, 'watch', true>): Promise<Watcher>;
export declare function run(options: RunnerOptions): Promise<void>;
export {};
