import { handleImportError } from './index.js';
// eslint-disable-next-line @typescript-eslint/naming-convention
function createLessPluginResolver(Less, options) {
    class ResolverFileManager extends Less.FileManager {
        constructor(options) {
            super();
            this.options = options;
        }
        supports() {
            return true;
        }
        async loadFile(filename, currentDirectory, options, environment) {
            // The http/https file is treated as an empty file.
            if (this.options.isIgnoredSpecifier(filename))
                return { contents: '', filename };
            const resolved = await this.options.resolver(filename, { request: currentDirectory });
            return super.loadFile(resolved, currentDirectory, options, environment);
        }
    }
    class LessPluginResolver {
        constructor(options) {
            this.minVersion = [2, 1, 1];
            this.options = options;
        }
        install(less, pluginManager) {
            pluginManager.addFileManager(new ResolverFileManager(this.options));
        }
    }
    return new LessPluginResolver(options);
}
export const createLessTransformer = () => {
    let less;
    return async (source, options) => {
        less ??= (await import('less').catch(handleImportError('less'))).default;
        const result = await less.render(source, {
            filename: options.from,
            sourceMap: {},
            plugins: [createLessPluginResolver(less, options)],
            syncImport: false, // Don't use `Less.FileManager#loadFileSync`.
        });
        return { css: result.css, map: result.map, dependencies: result.imports };
    };
};
//# sourceMappingURL=less-transformer.js.map