import { createRequire } from 'node:module';
import { resolve } from 'node:path';
import { default as postcss } from 'postcss';
const require = createRequire(import.meta.url);
const postcssrc = require('postcss-load-config');
function isDependencyMessage(message) {
    return message.type === 'dependency';
}
export const createPostcssTransformer = (postcssTransformerOptions) => {
    const cwd = postcssTransformerOptions?.cwd ?? process.cwd();
    const configSearchPath = postcssTransformerOptions?.postcssConfig
        ? resolve(cwd, postcssTransformerOptions?.postcssConfig)
        : cwd;
    return async (source, options) => {
        // NOTE: postcss-load-config cache the configuration file so is is not reloaded.
        const postcssConfig = await postcssrc({ cwd }, configSearchPath).catch((e) => {
            if (e instanceof Error && e.message.includes('No PostCSS Config found'))
                return undefined;
            throw e;
        });
        if (postcssConfig === undefined)
            return false;
        const result = await postcss(postcssConfig.plugins).process(source, {
            ...postcssConfig.options,
            from: options.from,
            map: { inline: false, absolute: true },
        });
        const dependencies = result.messages.filter(isDependencyMessage).map((message) => message.file);
        return { css: result.css, map: result.map, dependencies };
    };
};
//# sourceMappingURL=postcss-transformer.js.map